@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-05-19 11:33:16
-@LastEditTime: 2021-09-07 17:25:57
+@LastEditTime: 2021-09-07 19:19:55
 @LastEditors: HuangJianYi
 :description: 用户处理
 """
@@ -684,7 +684,7 @@ class GetPropGiveHandler(SevenBaseHandler):
         if prop_give.act_id != act_id:
             return self.reponse_json_error("Error", "不存在赠送信息")
         if prop_give.give_status == 1:
-            return self.reponse_json_error("Error", "已被领取")
+            return self.reponse_json_success({"prop_type": prop_give.prop_type, "num": 0})
         if prop_give.give_status == 2:
             return self.reponse_json_error("Error", "已失效,无法领取")
 
@@ -720,13 +720,13 @@ class GetPropGiveHandler(SevenBaseHandler):
         try:
             db_transaction.begin_transaction()
             prop_log_model.add_entity(prop_log)
-            prop_give_model.update_table("draw_open_id=%s,draw_user_nick=%s,give_status=1,modify_date=%s", params=[user_info.open_id, user_info.user_nick, self.get_now_datetime()])
+            prop_give_model.update_table("draw_open_id=%s,draw_user_nick=%s,give_status=1,modify_date=%s", where="guid=%s", params=[user_info.open_id, user_info.user_nick, self.get_now_datetime(), give_guid])
             user_detail_model.update_table(update_sql, "open_id=%s and act_id=%s", params=[open_id, act_id])
             db_transaction.commit_transaction()
 
         except Exception as ex:
             db_transaction.rollback_transaction()
-            self.logging_link_error("GetPropGiveHandler:" + str(ex) + ":" + str(update_sql))
+            self.logging_link_error("GetPropGiveHandler:" + str(ex))
             return self.reponse_json_error("Error", "系统繁忙,请稍后再试")
         return self.reponse_json_success({"prop_type": prop_give.prop_type, "num": 1})
 
